/**
* @license Apache-2.0
*
* Copyright (c) 2022 The Stdlib Authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

'use strict';

// MODULES //

var addon = require( './../src/addon.node' );


// MAIN //

/**
* Wrapper function exposing the C API to JavaScript.
*
* @private
* @param {Int32Array} v - input array
* @returns {Int32Array} input array
*
* @example
* var Int32Array = require( '@stdlib/array-int32' );
*
* var x = new Int32Array( 5 );
*
* wrapper( x );
* // x => <Int32Array>[ 1, 1, 1, 1, 1 ]
*/
function wrapper( v ) {
	addon( v );
	return v;
}


// EXPORTS //

module.exports = wrapper;
